==> circumstellar-0.1.11.tar.gz: lib/src/models/event_dispatcher.dart <==
part of circumstellar;

class EventDispatcher {
  DiscordClient _client;

  Future handleEvent(String eventName, dynamic data, bool isJsonObject) async {
    switch (eventName) {
      case 'READY':
        _readyController.add(null);
        break;
      case 'MESSAGE_CREATE':
        var messageModel = new Message(_client);
        await messageModel.updateModel(data, _client);
        // TODO: Message cache
        _messageCreateController.add(messageModel);
        break;
      case 'CHANNEL_UPDATE':
        var chan0 = (await _client.entities.getEntity(
                data['id'], ChannelTypeHelper.getTypeFromInt(data['type'])))
            as BaseChannel;
        await chan0.updateModel(data, _client);
        await _client.entities.updateEntity(
            data['id'], chan0, ChannelTypeHelper.getTypeFromChannel(chan0));
        _channelUpdateController.add(chan0);
        break;
      case 'CHANNEL_CREATE':
        var ent = (await _client.entities.getEntity(
            data['id'],
            ChannelTypeHelper.getTypeFromInt(data['type']),
            data)) as BaseChannel;
        _channelCreateController.add(ent);
        break;
      default:
        break;
    }
  }

  StreamController _messageCreateController = new StreamController.broadcast();
  Stream<Message> messageCreate = null;

  StreamController _readyController = new StreamController.broadcast();
  Stream<Null> ready = null;

  StreamController _channelUpdateController = new StreamController.broadcast();
  Stream<BaseChannel> channelUpdate = null;

  StreamController _channelCreateController = new StreamController.broadcast();
  Stream<BaseChannel> channelCreate = null;

  EventDispatcher(this._client) {
    this.messageCreate = _messageCreateController.stream;
    this.ready = _readyController.stream;
    this.channelUpdate = _channelUpdateController.stream;
    this.channelCreate = _channelCreateController.stream;
  }
}

==> circumstellar-0.1.20-dev1.tar.gz: lib/src/models/event_dispatcher.dart <==
part of circumstellar;

class EventDispatcher {
  DiscordClient _client;

  Future handleEvent(String eventName, dynamic data, bool isJsonObject) async {
    switch (eventName) {
      case 'READY':
        _readyController.add(null);
        break;
      case 'MESSAGE_CREATE':
        var msg0 = (await _client.entities
            .getEntity(data['id'], 'Message', data)) as Message;
        await msg0.updateModel(data, _client);
        await _client.entities.updateEntity(data['id'], msg0, 'Message');
        _messageCreateController.add(msg0);
        break;
      case 'CHANNEL_UPDATE':
        var chan0 = (await _client.entities.getEntity(
                data['id'], ChannelTypeHelper.getTypeFromInt(data['type'])))
            as BaseChannel;
        await chan0.updateModel(data, _client);
        await _client.entities.updateEntity(
            data['id'], chan0, ChannelTypeHelper.getTypeFromChannel(chan0));
        _channelUpdateController.add(chan0);
        break;
      case 'CHANNEL_CREATE':
        var ent = (await _client.entities.getEntity(
            data['id'],
            ChannelTypeHelper.getTypeFromInt(data['type']),
            data)) as BaseChannel;
        _channelCreateController.add(ent);
        break;
      case 'GUILD_CREATE':
        var guild = (await _client.entities
            .getEntity(data['id'], 'Guild', data)) as Guild;
        _guildCreateController.add(guild);
        break;
      case 'GUILD_UPDATE':
        var guild0 =
            (await _client.entities.getEntity(data['id'], 'Guild')) as Guild;
        await guild0.updateModel(data, _client);
        await _client.entities.updateEntity(data['id'], guild0, 'Guild');
        _guildUpdateController.add(guild0);
        break;
      default:
        break;
    }
  }

  StreamController _messageCreateController = new StreamController.broadcast();
  Stream<Message> messageCreate = null;

  StreamController _readyController = new StreamController.broadcast();
  Stream<Null> ready = null;

  StreamController _channelUpdateController = new StreamController.broadcast();
  Stream<BaseChannel> channelUpdate = null;

  StreamController _channelCreateController = new StreamController.broadcast();
  Stream<BaseChannel> channelCreate = null;

  StreamController _guildCreateController = new StreamController.broadcast();
  Stream<Guild> guildCreate = null;

  StreamController _guildUpdateController = new StreamController.broadcast();
  Stream<Guild> guildUpdate = null;

  EventDispatcher(this._client) {
    this.messageCreate = _messageCreateController.stream;
    this.ready = _readyController.stream;
    this.channelUpdate = _channelUpdateController.stream;
    this.channelCreate = _channelCreateController.stream;
    this.guildCreate = _guildCreateController.stream;
    this.guildUpdate = _guildUpdateController.stream;
  }
}
